<?php

namespace Drupal\advanced_sanitize\Event;

use Drupal\Component\EventDispatcher\Event;

/**
 * Defines the entity post-sanitize event.
 */
class FinishedSanitizeEvent extends Event {

  /**
   * Sanitized entity.
   *
   * @var bool
   */
  protected bool $success;

  /**
   * Sanitized entity.
   *
   * @var array
   */
  protected array $results;

  /**
   * Sanitized entity.
   *
   * @var array
   */
  protected array $operations;

  /**
   * Constructs a new PostSanitizeEvent object.
   *
   * @param bool $success
   *   Sanitized entity.
   * @param array $results
   *   Sanitized entity.
   * @param array $operations
   *   Sanitized entity.
   */
  public function __construct(bool $success, array $results, array $operations) {
    $this->success = $success;
    $this->results = $results;
    $this->operations = $operations;
  }

  /**
   * Gets the sanitized entity.
   *
   * @return bool
   *   Sanitized entity.
   */
  public function getSuccess(): bool {
    return $this->success;
  }

  /**
   * Gets the sanitized entity.
   *
   * @return array
   *   Sanitized entity.
   */
  public function getResults(): array {
    return $this->results;
  }

  /**
   * Gets the sanitized entity.
   *
   * @return array
   *   Sanitized entity.
   */
  public function getOperations(): array {
    return $this->operations;
  }

}
